# lionfuncs

[![Python Version](https://img.shields.io/badge/python-3.10%2B-blue)](https://www.python.org/downloads/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/lionfuncs?color=blue)
![Discord](https://img.shields.io/discord/1167495547670777866?color=7289da&label=discord&logo=discord)

## Overview

`lionfuncs` is a collection of utility functions and classes designed to simplify various programming tasks. The repository includes modules for algorithms, data handling, file operations, function call utilities, import handling, and data parsing.

## Installation

To install `lionfuncs`, use the following command:

```bash
pip install lionfuncs
```
